pub struct ApplyingAspect {
pub planet: &'static str,
pub aspect: &'static str,
pub degrees_to_exact: f64,
pub target_sign: &'static str,
}Expand description
A Ptolemaic aspect the Moon perfects before leaving its sign.
Fields
planet: &'static strPlanet aspected (Sun to Saturn).
aspect: &'static strAspect name, e.g. “Trine”.
degrees_to_exact: f64Degrees the Moon has left to travel to exactness.
target_sign: &'static strThe Moon’s current sign.