MoonStatus

Struct MoonStatus 

pub struct MoonStatus {
    pub void_of_course: bool,
    pub degrees_to_next_sign: f64,
    pub hours_to_next_sign: f64,
    pub next_sign: &'static str,
    pub speed_status: &'static str,
    pub applying_aspects: Vec<ApplyingAspect>,
    pub next_applying_aspect: Option<ApplyingAspect>,
    pub last_aspect: Option<SeparatingAspect>,
    pub separating_aspects: Vec<SeparatingAspect>,
}
The Moon’s condition in a horary chart.

Fields

void_of_course: bool

Whether the Moon makes no applying aspect before leaving its sign.

degrees_to_next_sign: f64

Degrees left in the current sign.

hours_to_next_sign: f64

Hours until the Moon enters the next sign, at its current speed.

next_sign: &'static str

Sign the Moon enters next.

speed_status: &'static str

“swift” (> 13.5°/day), “slow” (< 12.5°/day) or “average”.

applying_aspects: Vec<ApplyingAspect>

Applying aspects, closest first.

next_applying_aspect: Option<ApplyingAspect>

The closest applying aspect.

last_aspect: Option<SeparatingAspect>

The most recent separating aspect.

separating_aspects: Vec<SeparatingAspect>

Separating aspects, most recent first.